/*=============================================================================
Vitalnix/ACCDB - Unified Account Database
backends/slane.c - Server lane back-end
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
  -- License restrictions apply (Dual FAL/LGPL2).
  -- For details see doc/FAL.txt and doc/LGPL2.txt.
  $Id: slane.c,v 1.2 2004/03/11 14:42:34 hirogen2 Exp $
=============================================================================*/
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>

#include <accdb.h>
#include <accdb_int.h>

enum {
    CONF_READ = 0,
    CONF_FREE,
};

struct state {
    char *tcp_conn, *unix_conn;
};

static void read_config(struct state *, int);

MODULE_NAME("SLANE back-end");
MODULE_DESC("Server Lane support");
MODULE_INFO("Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004");

//-----------------------------------------------------------------------------
int q_open(void **state) {
    struct state *sp;
    if((sp = *state = calloc(1, sizeof(struct state))) == NULL) {
        return -errno;
    }

    read_config(sp, CONF_READ);
    return 0;
}

//-----------------------------------------------------------------------------
int q_usertrav(void *state, struct accdb_user *result) {
    return 0;
}

int q_userinfo(void *state, struct accdb_user *rq, struct accdb_user *dest,
 size_t s) {
    return 0;
}

int q_useradd(void *state, struct accdb_user *u) {
    return 0;
}

int q_usermod(void *state, struct accdb_user *sm, struct accdb_user *mm) {
    return 0;
}

int q_userdel(void *state, struct accdb_user *u) {
    return 0;
}

//-----------------------------------------------------------------------------
int q_grouptrav(void *state, struct accdb_group *result) {
    return 0;
}

int q_groupinfo(void *state, struct accdb_group *rq, struct accdb_group *dest,
 size_t s) {
    return 0;
}

int q_groupadd(void *state, struct accdb_group *g) {
    return 0;
}

int q_groupmod(void *state, struct accdb_group *sm, struct accdb_group *mm) {
    return 0;
}

int q_groupdel(void *state, struct accdb_group *g) {
    return 0;
}

//-----------------------------------------------------------------------------
int q_close(void *state) {
    struct state *sp = state;
    read_config(sp, CONF_FREE);
    return 0;
}

long p_sysctl(unsigned int req, ...) {
    int rv = 1;
    switch(req) {
        case ACCDB_ADDFLAGS:
        case ACCDB_DELFLAGS:
            rv = 0;
            break;
        default:
            rv = -ENOSYS;
            break;
    }
    return rv;
}

//-----------------------------------------------------------------------------
static void read_config(struct state *sp, int f) {
    const char *paths[] = {"backends/../vetc", "/etc", NULL};
    struct rconfig_opt table[] = {
        {"TCP_CONN",  RCONF_STRING, &sp->tcp_conn, NULL, NULL},
        {"UNIX_CONN", RCONF_STRING, &sp->unix_conn, NULL, NULL},
        {NULL},
    };

    if(f == CONF_FREE) { accdb_rconfig_free(table); }
    else { accdb_rconfig_pv(paths, "libaccdb/slane", table, RCONFIG_ONE); }
    return;
}

//==[ End of file ]============================================================
